@@ -7,16 +7,19 @@ import tempfile
 from datetime import datetime
 from functools import wraps
 from pathlib import Path
+from typing import Dict, List
 
 import click
 import requests
 import validators
 import yaml
 from lmterminal.cli import validate_model_name, validate_temperature
-from lmterminal.lib import prepare_and_generate_response
+from lmterminal.lib import DEFAULT_MODEL, prepare_and_generate_response
 from lmterminal.templates import TEMPLATES_DIR, get_template_content
 from strip_tags.lib import strip_tags
 
+from . import video_summarization
+
 
 def install_templates():
     """
@@ -51,7 +54,9 @@ def install_templates():
             # Update the config file with the copied template
             template_name = file.stem
             config["tools"][template_name] = str(dest_path / file.name)
-            click.echo(click.style(f"Installed `{template_name}` template.", fg="green"))
+            click.echo(
+                click.style(f"Installed `{template_name}` template.", fg="green")
+            )
 
     # Write the updated config back to the file
     with config_file.open("w") as file:
@@ -78,7 +83,7 @@ def common_options(function):
     @click.option(
         "-m",
         "--model",
-        default="gpt-3.5-turbo",
+        default=DEFAULT_MODEL,
         help="The model to use for the requests.",
         callback=validate_model_name,
     )
@@ -93,7 +98,10 @@ def common_options(function):
     @click.option(
         "--tokens",
         is_flag=True,
-        help=("Count the number of tokens in the prompt, and display the cost of the" " request."),
+        help=(
+            "Count the number of tokens in the prompt, and display the cost of the"
+            " request."
+        ),
     )
     @click.option(
         "--no-stream",
@@ -175,7 +183,9 @@ def define(ctx, model, emoji, word, temperature, tokens, no_stream, raw, debug):
     """
     Get a definition for a word.
     """
-    process_command(ctx, "define", model, emoji, word, temperature, tokens, no_stream, raw, debug)
+    process_command(
+        ctx, "define", model, emoji, word, temperature, tokens, no_stream, raw, debug
+    )
 
 
 @cli.command()
@@ -236,7 +246,9 @@ def commitgen(ctx, model, emoji, file, temperature, tokens, no_stream, raw, debu
 
     # Check if there are staged changes
     try:
-        diff_output = subprocess.check_output(["git", "diff", "--staged"]).decode("utf-8")
+        diff_output = subprocess.check_output(["git", "diff", "--staged"]).decode(
+            "utf-8"
+        )
     except subprocess.CalledProcessError as error:
         click.echo(click.style(f"Error occurred: {error}", fg="red"), err=True)
         sys.exit(1)
@@ -340,7 +352,9 @@ def commitgen(ctx, model, emoji, file, temperature, tokens, no_stream, raw, debu
 @click.argument("file_to_review", type=click.File("r"), required=False)
 @click.pass_context
 @common_options
-def codereview(ctx, model, emoji, file_to_review, temperature, tokens, no_stream, raw, debug):
+def codereview(
+    ctx, model, emoji, file_to_review, temperature, tokens, no_stream, raw, debug
+):
     """
     Generate a code review for a given file.
 
@@ -368,21 +382,37 @@ def summarize(ctx, model, emoji, source, temperature, tokens, no_stream, raw, de
     """
     Summarize the text, the content of a given file, or a webpage (provided as URL).
     """
-    source_str = " ".join(source)
+    template = "summarize"
+    source_str: str = " ".join(source)
 
-    prompt_input = ""
+    prompt_input: str = ""
 
-    if validators.url(source_str):
-        source_content = requests.get(source_str, timeout=5).text
-        prompt_input = strip_tags(input=source_content, minify=True)
+    # Determine what kind of source we are dealing with
+    if video_summarization.is_youtube_video(source_str):  # YouTube video
+        # Fetch the transcript of the YouTube video
+        transcript: List[Dict] = video_summarization.get_transcript(source_str)
+        # Format the transcript
+        prompt_input = video_summarization.format_transcript(transcript)
+        # Use the video summarization template for the prompt
+        template = "video_summarization"
+    elif validators.url(source_str):  # Webpage (hopefully)
+        try:
+            # Fetch the content of the webpage
+            source_content = requests.get(source_str, timeout=5).text
+        except requests.RequestException as error:
+            click.echo(click.style("Error occurred:", fg="red") + f" {error}", err=True)
+            sys.exit(1)
+        else:
+            prompt_input = strip_tags(input=source_content, minify=True)
     else:
+        # Read the content from `stdin`
         if source:
             content = "".join(source)
             prompt_input += content
 
     process_command(
         ctx,
-        "summarize",
+        template,
         model,
         emoji,
         prompt_input,
@@ -398,7 +428,9 @@ def summarize(ctx, model, emoji, source, temperature, tokens, no_stream, raw, de
 @click.argument("work_to_critique", nargs=-1, required=False)
 @click.pass_context
 @common_options
-def critique(ctx, model, emoji, work_to_critique, temperature, tokens, no_stream, raw, debug):
+def critique(
+    ctx, model, emoji, work_to_critique, temperature, tokens, no_stream, raw, debug
+):
     """
     Generate a critique for a given piece of work.
     """
@@ -477,7 +509,9 @@ def cheermeup(ctx, model, emoji, mood, temperature, tokens, no_stream, raw, debu
 @click.argument("study_material", nargs=-1, required=False)
 @click.pass_context
 @common_options
-def study(ctx, model, emoji, study_material, temperature, tokens, no_stream, raw, debug):
+def study(
+    ctx, model, emoji, study_material, temperature, tokens, no_stream, raw, debug
+):
     """
     Generate study material for a topic or from the content of the content of a file.
     """
@@ -499,7 +533,9 @@ def study(ctx, model, emoji, study_material, temperature, tokens, no_stream, raw
 @click.argument("library_name", nargs=-1, required=False)
 @click.pass_context
 @common_options
-def teachlib(ctx, model, emoji, library_name, temperature, tokens, no_stream, raw, debug):
+def teachlib(
+    ctx, model, emoji, library_name, temperature, tokens, no_stream, raw, debug
+):
     """
     Teach a library.
     """
@@ -594,7 +630,7 @@ def process_command(
     """
     Process a given command using a specific template and optional lines.
     """
-    if template in ["summarize", "commitgen"]:
+    if template in ["summarize", "commitgen", "video_summarization"]:
         prompt_input = "".join(prompt_input).strip()
     else:
         prompt_input = " ".join(prompt_input).strip()
@@ -616,6 +652,9 @@ def process_command(
             prompt_input = sys.stdin.read().strip()
             click.echo()
 
+    if not sys.stdout.isatty():
+        no_stream = True
+
     return prepare_and_generate_response(
         system=None,
         template=template,
